find_ccc: Find cluster-constant covariates in a data set.
Description
This function gives out logical indicators whether a variable is cluster-constant.
Usage
find_ccc(df, id_char)
Value
Gives a logical vector that indicates which variables of the dataframe have the same
realisation for all observations of one cluster/individual.
Arguments
df
some data frame
id_char
a character which is the column name for the cluster identifier.
Details
For uncorrected boosting of a mixed model the estimates for cluster constant covariates
might be biased as part of their effect is held in the random effects.
This bias is corrected by the underlying mermboost package.